<?php

/*-----------------------------------------------------------------------------------

	Plugin Name: Author Info Widget
	Plugin URI: http://www.bloompixel.com
	Description: A widget that displays Author Info.
	Version: 1.0

-----------------------------------------------------------------------------------*/

add_action( 'widgets_init', 'bloomy_author_widget' );  

// Register Widget
function bloomy_author_widget() {
    register_widget( 'bloomy_author_info_widget' );
}

// Widget Class
class bloomy_author_info_widget extends WP_Widget {

    function __construct() {
        parent::__construct(
        // Base ID of your widget
        'author_info_widget', 

        // Widget name will appear in UI
        esc_html__('(Bloomy) Author Info', 'bloomy'), 

        // Widget description
        array( 'description' => esc_html__('A widget that displays the selected author information', 'bloomy'), ) 
        );
    }
	
    /**
     * Outputs the content for the current Text widget instance.
     *
     * @global WP_Post $post
     *
     * @param array $args     Display arguments including 'before_title', 'after_title',
     *                        'before_widget', and 'after_widget'.
     * @param array $instance Settings for the current Text widget instance.
     */
	public function widget( $args, $instance ) {
		
		//Our variables from the widget settings.
        $title = ! empty( $instance['title'] ) ? $instance['title'] : '';
		$show_avatar = isset( $instance['show_avatar'] ) ? $instance['show_avatar'] : 1;
		$show_author_desc = isset( $instance['show_author_desc'] ) ? $instance['show_author_desc'] : 0;
		$author_list = isset( $instance['author_list'] ) ? $instance['author_list'] : '';
        
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		
		// Before Widget
		echo $args['before_widget'];
		
		// Display the widget title
		if ( ! empty( $title ) ) {
            echo $args['before_title'] . $title . $args['after_title'];
        }
		
		?>
		<!-- START WIDGET -->
		<div class="author-info-widget">
            <?php $bloomy_author_id = $author_list; ?>
                <?php if ( $show_avatar == 1 ) { ?>
                    <div class="author-avatar">
                        <?php
                            // Author Avatar
                            echo get_avatar( get_the_author_meta( 'email', $bloomy_author_id ), '150' );
                        ?>
                    </div>
                <?php } ?>
                <h4>
                    <?php
                        // Author Name
                        $bloomy_author_name = get_the_author_meta( 'display_name', $bloomy_author_id );
                        echo esc_attr( $bloomy_author_name );
                    ?>
                </h4>
                <?php if ( $show_author_desc == 1 ) { ?>
                    <div class="author-description">
                        <?php
                            // Author Description
                            $bloomy_author_description = get_the_author_meta( 'description', $bloomy_author_id );
                            $bloomy_allowed_html = array(
                                'a' => array(
                                    'href' => array(),
                                    'title' => array()
                                ),
                                'span' => array(
                                    'style' => array(),
                                    'class' => array()
                                ),
                                'br' => array(),
                                'em' => array(),
                                'strong' => array(),
                            );
                            echo wp_kses( $bloomy_author_description, $bloomy_allowed_html );
                        ?>
                    </div>
                <?php } ?>
        </div>
		<!-- END WIDGET -->
		<?php
		
		// After Widget
        echo $args['after_widget'];
	}
	
	// Update the widget
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		
        $instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['show_avatar'] = intval( $new_instance['show_avatar'] );
		$instance['show_author_desc'] = intval( $new_instance['show_author_desc'] );
		$instance['author_list'] = stripslashes( $new_instance['author_list'] );
		return $instance;
	}


	//Widget Settings
	public function form( $instance ) {
		//Set up some default widget settings.
		$defaults = array(
			'title'             => '',
			'show_avatar'       => 1,
			'show_author_desc'  => 0,
		);
		$instance = wp_parse_args( (array) $instance, $defaults );
		$show_avatar = isset( $instance[ 'show_avatar' ] ) ? esc_attr( $instance[ 'show_avatar' ] ) : 1;
		$show_author_desc = isset( $instance[ 'show_author_desc' ] ) ? esc_attr( $instance[ 'show_author_desc' ] ) : 1;
		$author_list = isset( $instance['author_list'] ) ? esc_attr( $instance['author_list'] ) : '';

		// Widget Title: Text Input
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e('Title:', 'bloomy'); ?></label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php if(!empty($instance['title'])) { echo esc_attr( $instance['title'] ); } ?>" class="widefat" type="text" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'author_list' ) ); ?>"><?php esc_html_e( 'Category:','bloomy' ); ?></label> 
			<?php wp_dropdown_users( Array(
                    'orderby'            => 'display_name', 
                    'order'              => 'ASC',
                    'echo'               => 1,
                    'selected'           => $author_list,
                    'show'               => 'display_name', 
                    'name'               => $this->get_field_name( 'author_list' ),
                    'id'                 => $this->get_field_id( 'author_list' ),
                ) ); ?>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id("show_avatar") ); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_avatar") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_avatar") ); ?>" value="1" <?php if (isset($instance['show_avatar'])) { checked( 1, esc_attr( $instance['show_avatar'] ), true ); } ?> />
				<?php esc_html_e( 'Show Author Avtar', 'bloomy'); ?>
			</label>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id("show_author_desc") ); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_author_desc") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_author_desc") ); ?>" value="1" <?php if (isset($instance['show_author_desc'])) { checked( 1, esc_attr( $instance['show_author_desc'] ), true ); } ?> />
				<?php esc_html_e( 'Show Author Description', 'bloomy'); ?>
			</label>
		</p>
		<?php
	}
}
?>