<?php

/*-----------------------------------------------------------------------------------

	Plugin Name: Recent Posts Widget
	Plugin URI: http://www.bloompixel.com
	Description: A widget that displays recent posts.
	Version: 1.0

-----------------------------------------------------------------------------------*/

add_action( 'widgets_init', 'bloomy_category_posts_widget' );  

// Register Widget
function bloomy_category_posts_widget() {
    register_widget( 'bloomy_category_widget' );
}

// Widget Class
class bloomy_category_widget extends WP_Widget {
function __construct() {
        parent::__construct(
        // Base ID of your widget
        'bloomy_cat_widget', 

        // Widget name will appear in UI
        esc_html__('(Bloomy) Category Posts', 'bloomy'), 

        // Widget description
        array( 'description' => esc_html__('A widget that displays the recent posts from a single category', 'bloomy'), ) 
        );
    }
	public function widget( $args, $instance ) {
		
		//Our variables from the widget settings.
        $title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__('Category Posts', 'bloomy');
        $posts = isset ( $instance['posts'] ) ? intval( $instance['posts'] ) : '4';
        $cat = isset( $instance[ 'cat' ] ) ? intval( $instance[ 'cat' ] ) : 0;
		$show_thumb = isset( $instance[ 'show_thumb' ] ) ? esc_attr( $instance[ 'show_thumb' ] ) : 1;
		$show_cat = isset( $instance[ 'show_cat' ] ) ? esc_attr( $instance[ 'show_cat' ] ) : 0;
		$show_author = isset( $instance[ 'show_author' ] ) ? esc_attr( $instance[ 'show_author' ] ) : 0;
		$show_date = isset( $instance[ 'show_date' ] ) ? esc_attr( $instance[ 'show_date' ] ) : 1;
		$show_comments = isset( $instance[ 'show_comments' ] ) ? esc_attr( $instance[ 'show_comments' ] ) : 0;
		$widget_style = isset( $instance['widget_style'] ) ? esc_attr( $instance['widget_style'] ) : 'style-one';
        
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		
		// Before Widget
        echo $args['before_widget'];
        
		$i = 1;
		// Display the widget title
		if ( ! empty( $title ) ) {
            echo $args['before_title'] . $title . $args['after_title'];
        }
		?>
		<!-- START WIDGET -->
		<div class="category-posts-widget category_posts">
		<ul class="category-posts">
			<?php
				query_posts( array('cat' => $cat, 'orderby' => 'date', 'order' => 'DESC', 'ignore_sticky_posts' => 1, 'showposts' => $posts) );
				if(have_posts()) : while (have_posts()) : the_post(); ?>
				<li>
					<?php if ( $show_thumb == 1 ) {
                        if (has_post_thumbnail()):
                            if ( $widget_style == 'style-one' ) { ?>
                                <div class="thumbnail">
                                    <a class="widgetthumb" href='<?php the_permalink(); ?>'>
                                        <?php the_post_thumbnail('widgetthumb'); ?>
                                    </a>
                                </div><?php
                            } else { ?>
                                <div class="thumbnail-big thumbnail clearfix">
                                    <a class="widgetthumb" href='<?php the_permalink(); ?>'>
                                        <?php the_post_thumbnail('featured390'); ?>
                                    </a>
                                </div><?php
                            }
                        endif;
					} ?>
					<div class="info">
						<span class="widgettitle"><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></span>
						<span class="meta">
							<?php if ( $show_author == 1 ) { ?>
								<span class="post-author">
                                    <?php the_author_posts_link(); ?>
                                </span>
							<?php } ?>
							<?php if ( $show_date == 1 ) { ?>
                                <span class="post-date">
								    <time datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>"> <?php the_time(get_option( 'date_format' )); ?></time>
                                </span>
							<?php } ?>
							<?php if ( $show_cat == 1 ) { ?>
								<span class="post-cats">
                                    <?php the_category(', '); ?>
                                </span>
							<?php } ?>
							<?php if ( $show_comments == 1 ) { ?>
								<span class="post-comments">
                                    <?php
                                        comments_popup_link( 
                                            esc_html__( '0 Comments', 'bloomy' ), 
                                            esc_html__( '1 Comment', 'bloomy' ), 
                                            esc_html__( '% Comments', 'bloomy' ),
                                            'comments-link',
                                            ''
                                        );
                                    ?>
                                </span>
							<?php } ?>
						</span>
					</div>
				</li>
			<?php endwhile; ?>
			<?php endif; ?>
			<?php wp_reset_query(); ?>
		</ul>
		</div>
		<!-- END WIDGET -->
		<?php
		
		// After Widget
        echo $args['after_widget'];
	}
	
	// Update the widget
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['posts'] = absint( $new_instance['posts'] );
		$instance['cat'] = stripslashes( $new_instance['cat'] );
        $instance['show_thumb'] = $new_instance['show_thumb'] ? 1 : 0;
        $instance['show_cat'] = $new_instance['show_cat'] ? 1 : 0;
        $instance['show_author'] = $new_instance['show_author'] ? 1 : 0;
        $instance['show_date'] = $new_instance['show_date'] ? 1 : 0;
        $instance['show_comments'] = $new_instance['show_comments'] ? 1 : 0;
		$instance['widget_style'] = stripslashes( $new_instance['widget_style'] );
		return $instance;
	}


	//Widget Settings
	public function form( $instance ) {
		//Set up some default widget settings.
		$defaults = array(
			'title' => esc_html__('Category Posts', 'bloomy'),
			'posts' => 4,
			'show_thumb' => 1,
			'show_cat' => 0,
			'show_author' => 0,
			'show_date' => 1,
			'show_comments' => 0,
		);
		$instance = wp_parse_args( (array) $instance, $defaults );
		$cat = isset( $instance[ 'cat' ] ) ? intval( $instance[ 'cat' ] ) : 0;
		$show_thumb = isset( $instance[ 'show_thumb' ] ) ? esc_attr( $instance[ 'show_thumb' ] ) : 1;
		$show_cat = isset( $instance[ 'show_cat' ] ) ? esc_attr( $instance[ 'show_cat' ] ) : 1;
		$show_author = isset( $instance[ 'show_author' ] ) ? esc_attr( $instance[ 'show_author' ] ) : 1;
		$show_date = isset( $instance[ 'show_date' ] ) ? esc_attr( $instance[ 'show_date' ] ) : 1;
		$show_comments = isset( $instance[ 'show_comments' ] ) ? esc_attr( $instance[ 'show_comments' ] ) : 1;
		$widget_style = isset( $instance['widget_style'] ) ? esc_attr( $instance['widget_style'] ) : '';

		// Widget Title: Text Input
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e('Title:', 'bloomy'); ?></label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php if(!empty($instance['title'])) { echo esc_attr( $instance['title'] ); } ?>" class="widefat" type="text" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'posts' ) ); ?>"><?php esc_html_e('Number of posts to show:','bloomy'); ?></label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'posts' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'posts' ) ); ?>" value="<?php echo intval( $instance['posts'] ); ?>" class="widefat" type="number" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'widget_style' ) ); ?>"><?php esc_html_e( 'Widget Style:','bloomy' ); ?></label> 
			<select id="<?php echo esc_attr( $this->get_field_id( 'widget_style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'widget_style' ) ); ?>" style="width:190px;" >
				<option value="style-one" <?php if ($widget_style == 'style-one') echo 'selected="selected"'; ?>><?php esc_html_e( 'Small Thumbnail','bloomy' ); ?></option>
				<option value="style-two" <?php if ($widget_style == 'style-two') echo 'selected="selected"'; ?>><?php esc_html_e( 'Big Thumbnail','bloomy' ); ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'cat' ) ); ?>"><?php esc_html_e( 'Category:','bloomy' ); ?></label> 
			<?php wp_dropdown_categories( Array(
						'orderby'            => 'ID', 
						'order'              => 'ASC',
						'show_count'         => 1,
						'hide_empty'         => 1,
						'hide_if_empty'      => true,
						'echo'               => 1,
						'selected'           => $cat,
						'hierarchical'       => 1, 
						'name'               => $this->get_field_name( 'cat' ),
						'id'                 => $this->get_field_id( 'cat' ),
						'taxonomy'           => 'category',
					) ); ?>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id("show_thumb") ); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_thumb") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_thumb") ); ?>" value="1" <?php if (isset($instance['show_thumb'])) { checked( 1, esc_attr( $instance['show_thumb'] ), true ); } ?> />
				<?php esc_html_e( 'Show Thumbnails', 'bloomy'); ?>
			</label>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id("show_cat") ); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_cat") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_cat") ); ?>" value="1" <?php if (isset($instance['show_cat'])) { checked( 1, esc_attr( $instance['show_cat'] ), true ); } ?> />
				<?php esc_html_e( 'Show Categories', 'bloomy'); ?>
			</label>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id("show_author") ); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_author") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_author") ); ?>" value="1" <?php if (isset($instance['show_author'])) { checked( 1, esc_attr( $instance['show_author'] ), true ); } ?> />
				<?php esc_html_e( 'Show Post Author', 'bloomy'); ?>
			</label>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id("show_date") ); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_date") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_date") ); ?>" value="1" <?php if (isset($instance['show_date'])) { checked( 1, esc_attr( $instance['show_date'] ), true ); } ?> />
				<?php esc_html_e( 'Show Post Date', 'bloomy'); ?>
			</label>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id("show_comments") ); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_comments") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_comments") ); ?>" value="1" <?php if (isset($instance['show_comments'])) { checked( 1, esc_attr( $instance['show_comments'] ), true ); } ?> />
				<?php esc_html_e( 'Show Post Comments', 'bloomy'); ?>
			</label>
		</p>
		<?php
	}
}
?>